@@ -191,6 +191,10 @@ def face_attribute(face_path, max_interval=configs.max_interval, version='none')
         face_upload_url = configs.deepface3_upload_url
         face_submit_url = configs.deepface3_submit_url
         face_result_url = configs.deepface3_result_url
+    if version == 'cgy-2':
+        face_upload_url = configs.deepface2_upload_url
+        face_submit_url = configs.deepface2_submit_url
+        face_result_url = configs.deepface2_result_url
     headers = {'Cookie': login_instance.cookie}
     with open(face_path, 'rb') as f1:
         filename1 = os.path.split(face_path)[-1]
@@ -201,7 +205,7 @@ def face_attribute(face_path, max_interval=configs.max_interval, version='none')
             filetype = 'image/jpg'
         if ext1 == '.png':
             filetype = 'image/png'
-        if ext1 == '.png':
+        if ext1 == '.jpeg':
             filetype = 'image/jpeg'
 
         uploaded_response1 = requests.post(face_upload_url, files={
